@@ -931,7 +931,7 @@ class Askdata(SignUp):
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        url = self.base_url + '/h2sql/smartjoin'
+        url = self.base_url + '/cfc/smartjoin'
 
         r = s.post(url=url, headers=self._headers, json=tables)
         r.raise_for_status()
