@@ -164,7 +164,7 @@ class AskdataPandasExtension:
         r.raise_for_status()
         return r
 
-    def join(self, with_query:str, workspace:str, how="inner", on="", left_on="", right_on="", lang="en"):
+    def join(self, with_query:str, workspace:str, how="inner", on=None, left_on=None, right_on=None, lang="en"):
 
         if self._env.lower() == 'dev':
             askdata_url = url_list['BASE_URL_ASKDATA_DEV']
