@@ -77,7 +77,7 @@ class TimeOperator(Enum):
 @dataclass
 class Condition:
     field: Field
-    operator: Union[SQLOperator, TimeOperator, str]
+    operator: Optional[Union[SQLOperator, TimeOperator, str]] = None
     value: Optional[List[Union[float, str]]] = None
     type: Optional[str] = None
     steps: Optional[str] = None
@@ -96,7 +96,7 @@ class Condition:
 
         if isinstance(self.operator, str):
             operator = self.operator
-        else:
+        elif isinstance(self.operator, SQLOperator) or isinstance(self.operator, TimeOperator):
             operator = self.operator.name
             if operator == "GOE":
                 operator = ">="
@@ -108,6 +108,8 @@ class Condition:
                 operator = ">"
             elif operator == "LT":
                 operator = "<"
+        else:
+            operator = None
         field_with_agg = self.field.column
         if self.field.aggregation is not None:
             if isinstance(self.field.aggregation, SQLFunction) or isinstance(self.field.aggregation,
@@ -142,10 +144,14 @@ class Condition:
                 where_condition = (
                         field_with_agg + " " + operator + " " + direction
                 )
-        else:
+        elif operator is not None:
             where_condition = (
                     field_with_agg + " " + operator
             )
+        else:
+            where_condition = (
+                field_with_agg
+            )
 
         return where_condition
 
